@@ -1,5 +1,7 @@
 ( cd opt/kde/share/doc/HTML/de/ark ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/ark ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/faq ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/faq ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kdf ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kdf ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kdm ; rm -rf common )
@@ -10,12 +12,12 @@
 ( cd opt/kde/share/doc/HTML/de/juk ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kpf ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kpf ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/ktuberling ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/ktuberling ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/amor ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/amor ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/karm ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/karm ; ln -sf /opt/kde/share/doc/HTML/de/common common )
-( cd opt/kde/share/doc/HTML/de/kate ; rm -rf common )
-( cd opt/kde/share/doc/HTML/de/kate ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kdvi ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kdvi ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kget ; rm -rf common )
@@ -30,6 +32,12 @@
 ( cd opt/kde/share/doc/HTML/de/kmix ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kodo ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kodo ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kolf ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kolf ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kpat ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kpat ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kpdf ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kpdf ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/korn ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/korn ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kppp ; rm -rf common )
@@ -76,6 +84,8 @@
 ( cd opt/kde/share/doc/HTML/de/kandy ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kcalc ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kcalc ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kdcop ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kdcop ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kdesu ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kdesu ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kcron ; rm -rf common )
@@ -106,6 +116,8 @@
 ( cd opt/kde/share/doc/HTML/de/ksysv ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/ktron ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/ktron ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kttsd ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kttsd ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kuser ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kuser ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kview ; rm -rf common )
@@ -114,6 +126,8 @@
 ( cd opt/kde/share/doc/HTML/de/kwin4 ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/lskat ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/lskat ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kgoldrunner ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kgoldrunner ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kcoloredit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kcoloredit ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/klipper ; rm -rf common )
@@ -128,8 +142,6 @@
 ( cd opt/kde/share/doc/HTML/de/klinkstatus ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kompare ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kompare ; ln -sf /opt/kde/share/doc/HTML/de/common common )
-( cd opt/kde/share/doc/HTML/de/kontact ; rm -rf common )
-( cd opt/kde/share/doc/HTML/de/kontact ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/konsole ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/konsole ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kcachegrind ; rm -rf common )
@@ -156,12 +168,16 @@
 ( cd opt/kde/share/doc/HTML/de/konquest ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kspaceduel ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kspaceduel ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kturtle ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kturtle ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kverbos ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kverbos ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kwallet ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kwallet ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kweather ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kweather ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kxsldbg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kxsldbg ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kwifimanager ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kwifimanager ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kbugbuster ; rm -rf common )
@@ -176,6 +192,8 @@
 ( cd opt/kde/share/doc/HTML/de/kbackgammon ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kaddressbook ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/glossary ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/glossary ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/common ; rm -rf fdl-license )
 ( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/fdl-license fdl-license )
 ( cd opt/kde/share/doc/HTML/de/common ; rm -rf qpl-license.html )
@@ -198,6 +216,8 @@
 ( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/6.png 6.png )
 ( cd opt/kde/share/doc/HTML/de/common ; rm -rf 7.png )
 ( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/7.png 7.png )
+( cd opt/kde/share/doc/HTML/de/common ; rm -rf top-right-konqueror.png )
+( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/top-right-konqueror.png top-right-konqueror.png )
 ( cd opt/kde/share/doc/HTML/de/common ; rm -rf 8.png )
 ( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/8.png 8.png )
 ( cd opt/kde/share/doc/HTML/de/common ; rm -rf 9.png )
@@ -228,6 +248,8 @@
 ( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/footer.html footer.html )
 ( cd opt/kde/share/doc/HTML/de/common ; rm -rf kde-common.css )
 ( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
+( cd opt/kde/share/doc/HTML/de/common ; rm -rf bottom-left.png )
+( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/bottom-left.png bottom-left.png )
 ( cd opt/kde/share/doc/HTML/de/common ; rm -rf appheader.html )
 ( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/appheader.html appheader.html )
 ( cd opt/kde/share/doc/HTML/de/common ; rm -rf doctop1.png )
@@ -240,8 +262,12 @@
 ( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
 ( cd opt/kde/share/doc/HTML/de/common ; rm -rf docheadergears.png )
 ( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
+( cd opt/kde/share/doc/HTML/de/common ; rm -rf top-middle.png )
+( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/top-middle.png top-middle.png )
 ( cd opt/kde/share/doc/HTML/de/common ; rm -rf fdl-license.html )
 ( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/fdl-license.html fdl-license.html )
+( cd opt/kde/share/doc/HTML/de/common ; rm -rf bottom-right.png )
+( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/bottom-right.png bottom-right.png )
 ( cd opt/kde/share/doc/HTML/de/common ; rm -rf doctop1a.png )
 ( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/doctop1a.png doctop1a.png )
 ( cd opt/kde/share/doc/HTML/de/common ; rm -rf 10.png )
@@ -258,6 +284,10 @@
 ( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/bottom2.png bottom2.png )
 ( cd opt/kde/share/doc/HTML/de/common ; rm -rf header.html )
 ( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/header.html header.html )
+( cd opt/kde/share/doc/HTML/de/common ; rm -rf bottom-middle.png )
+( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/bottom-middle.png bottom-middle.png )
+( cd opt/kde/share/doc/HTML/de/common ; rm -rf top-left.png )
+( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/top-left.png top-left.png )
 ( cd opt/kde/share/doc/HTML/de/common ; rm -rf gpl-license )
 ( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/gpl-license gpl-license )
 ( cd opt/kde/share/doc/HTML/de/common ; rm -rf kde-localised.css.template )
@@ -376,10 +406,38 @@
 ( cd opt/kde/share/doc/HTML/de/kcontrol/kcmtaskbar ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kcontrol/kcmfontinst ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kcontrol/kcmfontinst ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/artsbuilder ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/artsbuilder ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kicker-applets ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kicker-applets ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/konq-plugins/crashes ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/konq-plugins/crashes ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/konq-plugins/babel ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/konq-plugins/babel ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/konq-plugins/kuick ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/konq-plugins/kuick ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/konq-plugins/webarchiver ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/konq-plugins/webarchiver ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/konq-plugins/domtreeviewer ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/konq-plugins/domtreeviewer ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/konq-plugins/smbmounter ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/konq-plugins/smbmounter ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/konq-plugins/imgallery ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/konq-plugins/imgallery ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/konq-plugins/khtmlsettings ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/konq-plugins/khtmlsettings ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/konq-plugins/validators ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/konq-plugins/validators ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/konq-plugins ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/konq-plugins ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/konq-plugins/fsview ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/konq-plugins/fsview ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/konq-plugins/uachanger ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/konq-plugins/uachanger ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/konq-plugins/mediaplayer ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/konq-plugins/mediaplayer ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/konq-plugins/dirfilter ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/konq-plugins/dirfilter ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kalarm ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kalarm ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kamera ; rm -rf common )
@@ -398,6 +456,8 @@
 ( cd opt/kde/share/doc/HTML/de/kmessedwords ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kicker ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kicker ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/klatin ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/klatin ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/klines ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/klines ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kmines ; rm -rf common )
@@ -438,18 +498,22 @@
 ( cd opt/kde/share/doc/HTML/de/kreversi ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/noatun ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/noatun ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/opengl ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/opengl ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kdebugdialog ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kdebugdialog ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kblackbox ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kblackbox ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kcharselect ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kcharselect ; ln -sf /opt/kde/share/doc/HTML/de/common common )
-( cd opt/kde/share/doc/HTML/de/quanta ; rm -rf common )
-( cd opt/kde/share/doc/HTML/de/quanta ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kuickshow ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kuickshow ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kolourpaint ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kolourpaint ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kiconedit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kiconedit ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kmahjongg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kmahjongg ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/klettres ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/klettres ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kfouleggs ; rm -rf common )
@@ -458,14 +522,14 @@
 ( cd opt/kde/share/doc/HTML/de/kghostview ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/klickety ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/klickety ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kpovmodeler ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kpovmodeler ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kleopatra ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kleopatra ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kjumpingcube ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kjumpingcube ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kenolaba ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kenolaba ; ln -sf /opt/kde/share/doc/HTML/de/common common )
-( cd opt/kde/share/doc/HTML/de/kgpgcertmanager ; rm -rf common )
-( cd opt/kde/share/doc/HTML/de/kgpgcertmanager ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kwatchgnupg ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kwatchgnupg ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kworldclock ; rm -rf common )
@@ -520,5 +584,11 @@
 ( cd opt/kde/share/doc/HTML/de/umbrello ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/konqueror ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/konqueror ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kwordquiz ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kwordquiz ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/korganizer ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/korganizer ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/atlantik ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/atlantik ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/visualdict ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/visualdict ; ln -sf /opt/kde/share/doc/HTML/de/common common )
